
XEP-0422: Message Fastening
===========================

.. module:: slixmpp.plugins.xep_0422

.. autoclass:: XEP_0422
    :members:
    :exclude-members: session_bind, plugin_init, plugin_end


Stanza elements
---------------

.. automodule:: slixmpp.plugins.xep_0422.stanza
    :members:
    :undoc-members:

